@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.02.
 package DieTests;
 use vars '$VERSION';
-$VERSION = '1.32';
+$VERSION = '1.33';
 
 use warnings;
 use strict;
@@ -29,18 +29,18 @@ my $errno  = $!+0;
 my $errstr = "$!";
 
 sub process($)
-{
-    my ($err, $opt, $reason, $message) = die_decode shift;
-    $err =~ s/\d+\.?$/XX/;
+{   my $err   = shift;
+    my ($opt, $reason, $message) = die_decode $err;
+#   $err =~ s/\d+\.?$/XX/;
     my $errno = $opt->{errno}    || 'no errno';
     my $loc   = $opt->{location};
     my $loca  = $loc ? "$loc->[1]#XX" : 'no location';
     my $stack = join "\n",
                     map { join '#', $_->[0], $_->[1], 'XX' }
                         @{$opt->{stack}};
+
     my $r     = <<__RESULT;
 $reason: $message ($errno)
-$err
 $loca
 $stack
 __RESULT
@@ -63,7 +63,6 @@ eval { die "ouch" };
 my $die_text1 = $@;
 is(process($die_text1),  <<__OUT, "die");
 ERROR: ouch (no errno)
-ouch at t/DieTests.pm line XX
 t/DieTests.pm#XX
 
 __OUT
@@ -72,7 +71,6 @@ eval { die "ouch\n" };
 my $die_text2 = $@;
 is(process($die_text2),  <<__OUT, "die");
 ERROR: ouch (no errno)
-ouch
 no location
 
 __OUT
@@ -81,7 +79,6 @@ eval { $! = $errno; die "ouch $!" };
 my $die_text3 = $@;
 is(process($die_text3),  <<__OUT, "die");
 FAULT: ouch (3)
-ouch No such process at t/DieTests.pm line XX
 t/DieTests.pm#XX
 
 __OUT
@@ -90,7 +87,6 @@ eval { $! = $errno; die "ouch $!\n" };
 my $die_text4 = $@;
 is(process($die_text4),  <<__OUT, "die");
 FAULT: ouch (3)
-ouch No such process
 no location
 
 __OUT
@@ -101,7 +97,6 @@ eval { croak "ouch" };
 my $croak_text1 = $@;
 is(process($croak_text1),  <<__OUT, "croak");
 ERROR: ouch (no errno)
-ouch at t/41die.t line XX
 t/41die.t#XX
 
 __OUT
@@ -110,7 +105,6 @@ eval { croak "ouch\n" };
 my $croak_text2 = $@;
 is(process($croak_text2),  <<__OUT, "croak");
 ERROR: ouch (no errno)
-ouch
 t/41die.t#XX
 
 __OUT
@@ -119,7 +113,6 @@ eval { $! = $errno; croak "ouch $!" };
 my $croak_text3 = $@;
 is(process($croak_text3),  <<__OUT, "croak");
 FAULT: ouch (3)
-ouch No such process at t/41die.t line XX
 t/41die.t#XX
 
 __OUT
@@ -128,7 +121,6 @@ eval { $! = $errno; croak "ouch $!\n" };
 my $croak_text4 = $@;
 is(process($croak_text4),  <<__OUT, "croak");
 FAULT: ouch (3)
-ouch No such process
 t/41die.t#XX
 
 __OUT
@@ -139,7 +131,6 @@ eval { confess "ouch" };
 my $confess_text1 = $@;
 is(process($confess_text1),  <<__OUT, "confess");
 PANIC: ouch (no errno)
-ouch at t/DieTests.pm line XX
 t/DieTests.pm#XX
 eval {...}#t/DieTests.pm#XX
 DieTests::run_tests()#t/41die.t#XX
@@ -150,7 +141,6 @@ eval { confess "ouch\n" };
 my $confess_text2 = $@;
 is(process($confess_text2),  <<__OUT, "confess");
 PANIC: ouch (no errno)
-ouch
 t/DieTests.pm#XX
 eval {...}#t/DieTests.pm#XX
 DieTests::run_tests()#t/41die.t#XX
@@ -161,7 +151,6 @@ eval { $! = $errno; confess "ouch $!" };
 my $confess_text3 = $@;
 is(process($confess_text3),  <<__OUT, "confess");
 FAULT: ouch (3)
-ouch No such process at t/DieTests.pm line XX
 t/DieTests.pm#XX
 eval {...}#t/DieTests.pm#XX
 DieTests::run_tests()#t/41die.t#XX
@@ -180,7 +169,6 @@ eval { $! = $errno; confess "ouch $!\n" };
 my $confess_text4 = $@;
 is(process($confess_text4),  <<__OUT, "confess");
 FAULT: ouch (3)
-ouch No such process
 t/DieTests.pm#XX
 eval {...}#t/DieTests.pm#XX
 DieTests::run_tests()#t/41die.t#XX
